@@ -94,13 +94,6 @@ def deploy_group(
     default=False,
     help="Create development environment.",
 )
-@click.option(
-    "--force",
-    "force_overwrite",
-    is_flag=True,
-    default=False,
-    help="Remove existing build and overwrite with new one.",
-)
 @click.option(
     "--log-level",
     type=click.Choice(choices=LOGGING_LEVELS, case_sensitive=True),
@@ -157,7 +150,6 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
     deployment_type: str,
     output_dir: Optional[Path],
     dev_mode: bool,
-    force_overwrite: bool,
     registry: str,
     number_of_agents: Optional[int] = None,
     password: Optional[str] = None,
@@ -207,7 +199,6 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
             build_dir=build_dir,
             deployment_type=deployment_type,
             dev_mode=dev_mode,
-            force_overwrite=force_overwrite,
             number_of_agents=number_of_agents,
             password=password,
             packages_dir=packages_dir,
@@ -266,6 +257,24 @@ def run(build_dir: Path, no_recreate: bool, remove_orphans: bool) -> None:
     default=False,
     help="Apply environment variable when loading service config.",
 )
+@click.option(
+    "--docker",
+    "deployment_type",
+    flag_value=DockerComposeGenerator.deployment_type,
+    default=True,
+    help="Use docker as a backend.",
+)
+@click.option(
+    "--kubernetes",
+    "deployment_type",
+    flag_value=KubernetesGenerator.deployment_type,
+    help="Use kubernetes as a backend.",
+)
+@click.option(
+    "--no-deploy",
+    is_flag=True,
+    help="If set to true, the deployment won't run automatically",
+)
 @chain_selection_flag(help_string_format="Use {} chain to resolve the token id.")
 @click.pass_context
 @password_option(confirmation_prompt=True)
@@ -276,6 +285,8 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     chain_type: ChainType,
     skip_image: bool,
     n: Optional[int],
+    deployment_type: str,
+    no_deploy: bool,
     aev: bool = False,
     password: Optional[str] = None,
 ) -> None:
@@ -294,6 +305,8 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
             chain_type=ChainType(chain_type),
             skip_image=skip_image,
             n=n,
+            deployment_type=deployment_type,
             aev=aev,
             password=password,
+            no_deploy=no_deploy,
         )
