@@ -22,6 +22,7 @@
 import sys
 from pathlib import Path
 from typing import Optional
+from warnings import warn
 
 import click
 from aea.cli.ipfs_hash import hash_file, to_v0_string, to_v1_string
@@ -48,6 +49,16 @@ def generate_all(
     no_wrap: bool,
 ) -> None:
     """Generate IPFS hashes."""
+    message = (
+        "`autonomy hash all` command has been deprecated and will be removed on v2.0.0, "
+        "please use `autonomy packages lock` command to perform package hash updates"
+    )
+    warn(
+        message=message,
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
+    click.echo(message=message)
     packages_dir = Path(packages_dir).absolute()
     return_code = update_hashes(
         packages_dir, no_wrap, vendor=vendor, config_loader=load_configuration
