@@ -23,7 +23,7 @@ import re
 import tempfile
 from datetime import datetime
 from pathlib import Path
-from typing import Dict, List, Optional, Set, Tuple, Union, cast
+from typing import Dict, List, Optional, Set, Tuple, cast
 
 import click
 from aea.components.base import load_aea_package
@@ -40,6 +40,7 @@ from aea.configurations.data_types import (
     PublicId,
 )
 from aea.configurations.loader import load_configuration_object
+from aea.crypto.base import LedgerApi
 from aea.package_manager.v1 import PackageManagerV1
 from aea_cli_ipfs.ipfs_utils import IPFSTool
 
@@ -49,7 +50,6 @@ from autonomy.analyse.logs.base import (
     EXIT_ROUND_REGEX,
     LOGS_DB,
     LogRow,
-    TIME_FORMAT,
 )
 from autonomy.analyse.logs.collection import FromDirectory, LogCollection
 from autonomy.analyse.logs.db import AgentLogsDB
@@ -126,6 +126,12 @@ class ParseLogs:
 
         return self._collection.agents
 
+    @property
+    def n_agents(self) -> int:
+        """Available agents."""
+
+        return self._collection.n_agents
+
     def from_dir(self, logs_dir: Path) -> "ParseLogs":
         """From directory"""
 
@@ -157,8 +163,8 @@ class ParseLogs:
     def select(  # pylint: disable=too-many-arguments
         self,
         agents: List[str],
-        start_time: Optional[Union[str, datetime]],
-        end_time: Optional[Union[str, datetime]],
+        start_time: Optional[datetime],
+        end_time: Optional[datetime],
         log_level: Optional[str],
         period: Optional[int],
         round_name: Optional[str],
@@ -166,12 +172,6 @@ class ParseLogs:
     ) -> "ParseLogs":
         """Query and return results."""
 
-        if start_time is not None:
-            start_time = datetime.strptime(cast(str, start_time), TIME_FORMAT)
-
-        if end_time is not None:
-            end_time = datetime.strptime(cast(str, end_time), TIME_FORMAT)
-
         results = {}
         for agent in agents:
             results[agent] = self._dbs[agent].select(
@@ -347,8 +347,8 @@ def _get_chained_abci_skill(
 
 def _get_ipfs_pins(is_on_chain_check: bool = False) -> Set[str]:
     """Get IPFS pins."""
-    ipfs_tool = IPFSTool()
     if is_on_chain_check:
+        ipfs_tool = IPFSTool()
         if not ipfs_tool.daemon.is_started():
             raise click.ClickException("Cannot connect to the IPFS daemon.")
         return ipfs_tool.all_pins()
@@ -356,6 +356,25 @@ def _get_ipfs_pins(is_on_chain_check: bool = False) -> Set[str]:
     return set()
 
 
+def _get_on_chain_service_id(
+    ledger_api: LedgerApi,
+    chain_type: ChainType,
+    token_id: int,
+) -> PackageId:
+    """Get on chain service ID with package hash"""
+    service_info = resolve_component_id(
+        ledger_api=ledger_api,
+        contract_address=ContractConfigs.service_registry.contracts[chain_type],
+        token_id=cast(int, token_id),
+        is_service=True,
+    )
+    package_hash = cast(str, service_info["code_uri"]).replace("ipfs://", "")
+    public_id = PublicId.from_str(service_info["name"]).with_hash(
+        package_hash=package_hash
+    )
+    return PackageId(package_type=PackageType.SERVICE, public_id=public_id)
+
+
 def check_service_readiness(  # pylint: disable=too-many-locals
     token_id: Optional[int],
     public_id: Optional[PublicId],
@@ -371,18 +390,10 @@ def check_service_readiness(  # pylint: disable=too-many-locals
 
     if is_on_chain_check:
         try:
-            service_info = resolve_component_id(
+            service_id = _get_on_chain_service_id(
                 ledger_api=ledger_api,
-                contract_address=ContractConfigs.service_registry.contracts[chain_type],
+                chain_type=chain_type,
                 token_id=cast(int, token_id),
-                is_service=True,
-            )
-            package_hash = cast(str, service_info["code_uri"]).replace("ipfs://", "")
-            public_id = PublicId.from_str(service_info["name"]).with_hash(
-                package_hash=package_hash
-            )
-            service_id = PackageId(
-                package_type=PackageType.SERVICE, public_id=public_id
             )
         except FailedToRetrieveComponentMetadata as e:
             raise click.ClickException(
@@ -431,6 +442,7 @@ def check_service_readiness(  # pylint: disable=too-many-locals
             service_config=service_config,
             is_on_chain_check=is_on_chain_check,
         )
+
         service_analyser.check_on_chain_state(
             ledger_api=ledger_api,
             chain_type=chain_type,
