@@ -36,13 +36,14 @@ from autonomy.deploy.constants import (
     DEFAULT_ENCODING,
     KEY_SCHEMA_PRIVATE_KEY,
     KUBERNETES_AGENT_KEY_NAME,
-    TENDERMINT_CONFIGURATION_OVERRIDES,
 )
 from autonomy.deploy.generators.kubernetes.templates import (
     AGENT_NODE_TEMPLATE,
     AGENT_SECRET_TEMPLATE,
     CLUSTER_CONFIGURATION_TEMPLATE,
     HARDHAT_TEMPLATE,
+    PORTS_CONFIG_DEPLOYMENT,
+    PORT_CONFIG_DEPLOYMENT,
 )
 
 
@@ -82,6 +83,7 @@ class KubernetesGenerator(BaseDeploymentGenerator):
         agent_ix: int,
         number_of_agents: int,
         agent_vars: Dict[str, Any],
+        agent_ports: Optional[Dict[int, int]] = None,
     ) -> str:
         """Build agent deployment."""
 
@@ -89,6 +91,16 @@ class KubernetesGenerator(BaseDeploymentGenerator):
             [f'"--hostname=abci{i}"' for i in range(number_of_agents)]
         )
 
+        agent_ports_deployment = ""
+        if agent_ports is not None:
+            port_mappings = map(
+                lambda x: PORT_CONFIG_DEPLOYMENT.format(port=x[0]),
+                agent_ports.items(),
+            )
+            agent_ports_deployment = "\n".join(
+                [PORTS_CONFIG_DEPLOYMENT, *port_mappings]
+            )
+
         agent_deployment = AGENT_NODE_TEMPLATE.format(
             runtime_image=runtime_image,
             validator_ix=agent_ix,
@@ -98,6 +110,7 @@ class KubernetesGenerator(BaseDeploymentGenerator):
             tendermint_image_name=TENDERMINT_IMAGE_NAME,
             tendermint_image_version=TENDERMINT_IMAGE_VERSION,
             log_level=self.service_builder.log_level,
+            agent_ports_deployment=agent_ports_deployment,
         )
         agent_deployment_yaml = yaml.load_all(agent_deployment, Loader=yaml.FullLoader)  # type: ignore
         resources = []
@@ -136,14 +149,6 @@ class KubernetesGenerator(BaseDeploymentGenerator):
 
         return self
 
-    def _apply_cluster_specific_tendermint_params(  # pylint: disable= no-self-use
-        self, agent_params: List
-    ) -> List:
-        """Override the tendermint params to point at the localhost."""
-        for agent in agent_params:
-            agent.update(TENDERMINT_CONFIGURATION_OVERRIDES[self.deployment_type])
-        return agent_params
-
     def generate(
         self,
         image_version: Optional[str] = None,
@@ -167,7 +172,6 @@ class KubernetesGenerator(BaseDeploymentGenerator):
             ...
 
         agent_vars = self.service_builder.generate_agents()  # type:ignore
-        agent_vars = self._apply_cluster_specific_tendermint_params(agent_vars)
         runtime_image = OAR_IMAGE.format(
             image_author=self.image_author,
             agent=self.service_builder.service.agent.name,
@@ -181,6 +185,11 @@ class KubernetesGenerator(BaseDeploymentGenerator):
                     agent_ix=i,
                     number_of_agents=self.service_builder.service.number_of_agents,
                     agent_vars=agent_vars[i],
+                    agent_ports=(
+                        self.service_builder.service.deployment_config.get("agent", {})
+                        .get("ports", {})
+                        .get(i)
+                    ),
                 )
                 for i in range(self.service_builder.service.number_of_agents)
             ]
@@ -194,11 +203,7 @@ class KubernetesGenerator(BaseDeploymentGenerator):
     ) -> "KubernetesGenerator":
         """Write output to build dir"""
 
-        if self.use_tm_testnet_setup:
-            output = "---\n".join([self.output, cast(str, self.tendermint_job_config)])
-        else:
-            output = self.output
-
+        output = "---\n".join([self.output, cast(str, self.tendermint_job_config)])
         if not self.build_dir.is_dir():  # pragma: no cover
             self.build_dir.mkdir()
         with open(
