@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -160,6 +160,9 @@ spec:
       storage: 1000M
 """
 
+PORTS_CONFIG_DEPLOYMENT = "        ports:"
+
+PORT_CONFIG_DEPLOYMENT = "          - containerPort: {port}"
 
 AGENT_NODE_TEMPLATE: str = """apiVersion: v1
 kind: Service
@@ -204,11 +207,11 @@ spec:
         imagePullPolicy: Always
         resources:
           limits:
-            memory: "1512Mi"
-            cpu: "1"
+            memory: "350Mi"
+            cpu: "0.05"
           requests:
             cpu: "0.05"
-            memory: "128Mi"
+            memory: "350Mi"
         ports:
           - containerPort: 26656
           - containerPort: 26657
@@ -243,10 +246,10 @@ spec:
         resources:
           limits:
             memory: "1512Mi"
-            cpu: "1"
+            cpu: "0.5"
           requests:
-            cpu: "0.05"
-            memory: "128Mi"
+            cpu: "0.5"
+            memory: "1512Mi"
         env:
           - name: HOSTNAME
             value: "agent-node-{validator_ix}"
@@ -265,6 +268,7 @@ spec:
             name: nodes
           - mountPath: /agent_key
             name: agent-key
+{agent_ports_deployment}
       volumes:
         - name: agent-key
           secret:
