@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -29,6 +29,8 @@ from aea_test_autonomy.fixture_helpers import (  # noqa: F401
     flask_tendermint,
     hardhat_addr,
     hardhat_port,
+    ipfs_daemon,
+    ipfs_domain,
     key_pairs,
     registries_scope_class,
     tendermint_port,
