@@ -98,7 +98,7 @@ DEFAULT_RPC_PORT = 26657
 DEFAULT_LISTEN_ADDRESS = "0.0.0.0"  # nosec
 DEFAULT_P2P_LISTEN_ADDRESS = f"{_TCP}{DEFAULT_LISTEN_ADDRESS}:{DEFAULT_P2P_PORT}"
 DEFAULT_RPC_LISTEN_ADDRESS = f"{_TCP}{LOCALHOST}:{DEFAULT_RPC_PORT}"
-MAX_READ_IN_BYTES = 2 ** 20  # Max we'll consume on a read stream (1 MiB)
+MAX_READ_IN_BYTES = 2**20  # Max we'll consume on a read stream (1 MiB)
 MAX_VARINT_BYTES = 10  # Max size of varint we support
 DEFAULT_TENDERMINT_LOG_FILE = "tendermint.log"
 
@@ -993,31 +993,21 @@ class TcpServerChannel:  # pylint: disable=too-many-instance-attributes
 
     async def _handle_message(self, message: Request, peer_name: str) -> None:
         """Handle a single message from a peer."""
-        # TODO: remove the following try/except and logs, https://github.com/valory-xyz/open-autonomy/issues/1655
         try:
             req_type = message.WhichOneof("value")
-            self.logger.info(
-                f"Received message of type: {req_type} on abci connection."
-            )
             result = _TendermintProtocolDecoder.process(
                 message, self._dialogues, str(self.target_skill_id)
             )
-            self.logger.info(f"Received result={result} from processing message.")
             if result is not None:
                 request, dialogue = result
                 # associate request to peer, so we remember who to reply to
                 self._request_id_to_socket[
                     dialogue.incomplete_dialogue_label
                 ] = peer_name
-                self.logger.info(
-                    f"Associated request with id={dialogue.incomplete_dialogue_label} to peer={peer_name}."
-                )
                 envelope = Envelope(
                     to=request.to, sender=request.sender, message=request
                 )
-                self.logger.info(f"Created envelope={envelope}.")
                 await cast(asyncio.Queue, self.queue).put(envelope)
-                self.logger.info(f"Successfully put envelope in queue={envelope}.")
             else:  # pragma: nocover
                 self.logger.warning(f"Decoded request {req_type} was not a match.")
         except Exception as e:  # pylint: disable=broad-except  # pragma: no cover
@@ -1151,7 +1141,7 @@ class TendermintParams:  # pylint: disable=too-few-public-methods  # pragma: no
         return kwargs
 
 
-class TendermintNode:  # pragma: no cover (covered via deployments/Dockerfiles/tendermint/tendermint.py)
+class TendermintNode:
     """A class to manage a Tendermint node."""
 
     def __init__(self, params: TendermintParams, logger: Optional[Logger] = None):
@@ -1272,12 +1262,17 @@ class TendermintNode:  # pragma: no cover (covered via deployments/Dockerfiles/t
                     for trigger in [
                         # this occurs when we lose connection from the tm side
                         "RPC HTTP server stopped",
-                        # this occurs when we lose connection from the AEA side.
-                        "Stopping abci.socketClient for error: read message: EOF module=abci-client connection=",
+                        # whenever the node is stopped because of a closed connection
+                        # from on any of the tendermint modules (abci, p2p, rpc, etc)
+                        # we restart the node
+                        "Stopping abci.socketClient for error: read message: EOF",
                     ]:
                         if line.find(trigger) >= 0:
                             self._stop_tm_process()
-                            self._start_tm_process()
+                            # we can only reach this step if monitoring was activated
+                            # so we make sure that after reset the monitoring continues
+                            monitoring = True
+                            self._start_tm_process(monitoring)
                             self.write_line(
                                 f"Restarted the HTTP RPC server, as a connection was dropped with message:\n\t\t {line}\n"
                             )
@@ -1285,13 +1280,18 @@ class TendermintNode:  # pragma: no cover (covered via deployments/Dockerfiles/t
                 self.write_line(f"Error!: {str(e)}")
         self.write_line("Monitoring thread terminated\n")
 
-    def reset_genesis_file(self, genesis_time: str, initial_height: str) -> None:
+    def reset_genesis_file(
+        self, genesis_time: str, initial_height: str, period_count: str
+    ) -> None:
         """Reset genesis file."""
 
         genesis_file = Path(str(self.params.home), "config", "genesis.json")
         genesis_config = json.loads(genesis_file.read_text(encoding=ENCODING))
         genesis_config["genesis_time"] = genesis_time
         genesis_config["initial_height"] = initial_height
+        # chain id should be max 50 chars.
+        # this means that the app would theoretically break when a 40-digit period is reached
+        genesis_config["chain_id"] = f"autonolas-{period_count}"
         genesis_file.write_text(json.dumps(genesis_config, indent=2), encoding=ENCODING)
 
 
@@ -1464,10 +1464,6 @@ class ABCIServerConnection(Connection):  # pylint: disable=too-many-instance-att
         self.channel = cast(Union[TcpServerChannel, GrpcServerChannel], self.channel)
         try:
             message = await self.channel.get_message()
-            # TODO: remove the following, https://github.com/valory-xyz/open-autonomy/issues/1655
-            self.logger.info(
-                f"Received message={message} on `ABCIServerConnection.receive()`."
-            )
             return message
         except CancelledError:  # pragma: no cover
             return None
