@@ -69,11 +69,9 @@ class RegistrationBaseBehaviour(BaseBehaviour, ABC):
         """
 
         with self.context.benchmark_tool.measure(self.behaviour_id).local():
-            initialisation = json.dumps(
-                self.synchronized_data.db.setup_data, sort_keys=True
-            )
+            serialized_db = self.synchronized_data.db.serialize()
             payload = RegistrationPayload(
-                self.context.agent_address, initialisation=initialisation
+                self.context.agent_address, initialisation=serialized_db
             )
 
         with self.context.benchmark_tool.measure(self.behaviour_id).consensus():
@@ -92,6 +90,16 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
     updated_genesis_data: Dict[str, Any] = {}
     collection_complete: bool = False
 
+    @property
+    def initial_tm_configs(self) -> Dict[str, Dict[str, Any]]:
+        """A mapping of the other agents' addresses to their initial Tendermint configuration."""
+        return self.context.state.initial_tm_configs
+
+    @initial_tm_configs.setter
+    def initial_tm_configs(self, configs: Dict[str, Dict[str, Any]]) -> None:
+        """A mapping of the other agents' addresses to their initial Tendermint configuration."""
+        self.context.state.initial_tm_configs = configs
+
     class LogMessages(Enum):
         """Log messages used in RegistrationStartupBehaviour"""
 
@@ -126,14 +134,6 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
             """For ease of use in formatted string literals"""
             return self.value
 
-    @property
-    def registered_addresses(self) -> Dict[str, Dict[str, Any]]:
-        """Agent addresses registered on-chain for the service"""
-        return cast(
-            Dict[str, Dict[str, Any]],
-            self.synchronized_data.db.get("registered_addresses", {}),
-        )
-
     @property
     def tendermint_parameter_url(self) -> str:
         """Tendermint URL for obtaining and updating parameters"""
@@ -255,7 +255,7 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
             return False
 
         # put service info in the shared state for p2p message handler
-        info: Dict[str, Dict[str, str]] = dict.fromkeys(registered_addresses)
+        info: Dict[str, Dict[str, str]] = {i: {} for i in registered_addresses}
         tm_host, tm_port = parse_tendermint_p2p_url(url=self.params.tendermint_p2p_url)
         validator_config = dict(
             hostname=tm_host,
@@ -265,7 +265,7 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
             peer_id=self.local_tendermint_params["peer_id"],
         )
         info[self.context.agent_address] = validator_config
-        self.synchronized_data.db.update(registered_addresses=info)
+        self.initial_tm_configs = info
         log_message = self.LogMessages.response_service_info.value
         self.context.logger.info(f"{log_message}: {info}")
         return True
@@ -290,7 +290,9 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
     def request_tendermint_info(self) -> Generator[None, None, bool]:
         """Request Tendermint info from other agents"""
 
-        still_missing = {k for k, v in self.registered_addresses.items() if not v}
+        still_missing = {k for k, v in self.initial_tm_configs.items() if not v} - {
+            self.context.agent_address
+        }
         log_message = self.LogMessages.request_others
         self.context.logger.info(f"{log_message}: {still_missing}")
 
@@ -306,9 +308,9 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
         # we wait for the messages that were put in the outbox.
         yield from self.sleep(self.params.sleep_time)
 
-        if all(self.registered_addresses.values()):
+        if all(self.initial_tm_configs.values()):
             log_message = self.LogMessages.collection_complete
-            self.context.logger.info(f"{log_message}: {self.registered_addresses}")
+            self.context.logger.info(f"{log_message}: {self.initial_tm_configs}")
             self.collection_complete = True
         return self.collection_complete
 
@@ -341,7 +343,7 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
         """Make HTTP POST request to update agent's local Tendermint node"""
 
         url = self.tendermint_parameter_url
-        genesis_data = self.format_genesis_data(self.registered_addresses)
+        genesis_data = self.format_genesis_data(self.initial_tm_configs)
         log_message = self.LogMessages.request_update
         self.context.logger.info(f"{log_message}: {genesis_data}")
 
@@ -420,8 +422,10 @@ class RegistrationStartupBehaviour(RegistrationBaseBehaviour):
                 yield from self.sleep(self.params.sleep_time)
                 return
 
-        # make service registry contract call
-        if not self.registered_addresses:
+        # if the agent doesn't have it's tm config info set, then make service registry contract call
+        # to get the rest of the agents, so we can get their tm config info later
+        info = self.initial_tm_configs.get(self.context.agent_address, None)
+        if info is None:
             successful = yield from self.get_addresses()
             if not successful:
                 yield from self.sleep(self.params.sleep_time)
