@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -48,11 +48,11 @@ class TestDummyRound(BaseRoundTestClass):
 
         test_round = DummyRound(
             synchronized_data=self.synchronized_data,
-            consensus_params=self.consensus_params,
         )
 
         first_payload, *payloads = [
-            DummyPayload(sender=participant) for participant in self.participants
+            DummyPayload(sender=participant, content=count)
+            for count, participant in enumerate(self.participants)
         ]
 
         test_round.process_payload(first_payload)
@@ -64,7 +64,7 @@ class TestDummyRound(BaseRoundTestClass):
 
         actual_next_behaviour = BaseSynchronizedData(
             AbciAppDB(
-                setup_data=dict(participants=[frozenset(test_round.collection.keys())]),
+                setup_data=dict(participants=[tuple(test_round.collection)]),
             )
         )
 
