@@ -24,11 +24,16 @@ from copy import deepcopy
 from typing import Any, Dict, List, Tuple
 from unittest import mock
 
-import pytest
-from aea.configurations.base import AgentConfig
-from aea.configurations.data_types import ComponentId, ComponentType, PublicId
+from aea.configurations.base import AgentConfig, SkillConfig
+from aea.configurations.data_types import (
+    ComponentId,
+    ComponentType,
+    PackageId,
+    PackageType,
+    PublicId,
+)
 from aea.helpers.cid import to_v0
-from aea_cli_ipfs.ipfs_utils import IPFSTool
+from aea_cli_ipfs.ipfs_utils import IPFSDaemon, IPFSTool
 
 from autonomy.analyse.service import ServiceAnalyser
 from autonomy.configurations.base import Service
@@ -36,6 +41,7 @@ from autonomy.configurations.base import Service
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
+DUMMY_SERVICE_HASH = "bafybeib56ojddzexxbapowofypmpk6zeznqaumwgj7ftneb5ua6sk5k5vj"
 DUMMY_AGENT_HASH = "bafybeib56ojddzexxbapowofypmpk6zeznqaumwgj7ftneb5ua6sk5k5vm"
 DUMMY_LEDGER_CONNECTION_HASH = (
     "bafybeib56ojddzexxbapowofypmpk6zeznqaumwgj7ftneb5ua6sk5k5vn"
@@ -73,11 +79,11 @@ def get_dummy_overrides_skill() -> Dict:
             "params": {
                 "args": {
                     "message": "Hello, World!",
+                    "reset_pause_duration": 10,
                     "setup": {
-                        "safe_contract_address": [
-                            ["0xAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"]
-                        ],
-                        "all_participants": [["0x"]],
+                        "safe_contract_address": "0xAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA",
+                        "all_participants": ["0x"],
+                        "consensus_threshold": None,
                     },
                     "tendermint_url": "tendermint_url",
                     "tendermint_com_url": "tendermint_com_url",
@@ -156,11 +162,75 @@ def get_dummy_agent_config() -> Dict:
     }
 
 
-@pytest.mark.skip
+def get_dummy_skill_config() -> Dict:
+    """Returns dummy skill config"""
+    return {
+        "name": "abci_skill",
+        "author": "valory",
+        "version": "0.1.0",
+        "type": "skill",
+        "description": "Hello World ABCI application.",
+        "license": "Apache-2.0",
+        "aea_version": ">=1.0.0, <2.0.0",
+        "fingerprint": {},
+        "fingerprint_ignore_patterns": [],
+        "connections": [],
+        "contracts": [],
+        "protocols": [],
+        "skills": [
+            "valory/abstract_round_abci:0.1.0:bafybeiami2y2uwvtmjf76hl3jvfahujdir5docjby6erdyjl66ekoblesi"
+        ],
+        "behaviours": {"main": {"args": {}, "class_name": "DummyBehaviour"}},
+        "handlers": {},
+        "models": {
+            "params": {
+                "args": {
+                    "cleanup_history_depth": 1,
+                    "cleanup_history_depth_current": None,
+                    "drand_public_key": "drand_public_key",
+                    "genesis_config": {},
+                    "keeper_timeout": 30,
+                    "max_attempts": 10,
+                    "max_healthcheck": 120,
+                    "observation_interval": 10,
+                    "on_chain_service_id": None,
+                    "request_retry_delay": 1,
+                    "request_timeout": 10,
+                    "reset_pause_duration": 10,
+                    "reset_tendermint_after": 2,
+                    "retry_attempts": 400,
+                    "retry_timeout": 3,
+                    "round_timeout_seconds": 30,
+                    "service_id": "hello_world_abci",
+                    "service_registry_address": None,
+                    "setup": {
+                        "all_participants": "- '0x0000000000000000000000000000000000000000'",
+                        "safe_contract_address": "0x0000000000000000000000000000000000000000",
+                        "consensus_threshold": None,
+                    },
+                    "share_tm_config_on_startup": False,
+                    "sleep_time": 1,
+                    "tendermint_check_sleep_delay": 3,
+                    "tendermint_com_url": "http://localhost:8080",
+                    "tendermint_max_retries": 5,
+                    "tendermint_p2p_url": "localhost:26656",
+                    "tendermint_url": "http://localhost:26657",
+                    "tx_timeout": 10,
+                },
+                "class_name": "Params",
+            },
+        },
+        "dependencies": {},
+        "is_abstract": False,
+    }
+
+
 class BaseAnalyseServiceTest(BaseCliTest):
     """Base class for service verifier tests"""
 
     cli_options: Tuple[str, ...] = ("analyse", "service")
+    public_id_option = ("--public-id", "valory/service")
+    token_id_option = ("--token-id", "1")
 
     @classmethod
     def setup_class(cls) -> None:
@@ -169,13 +239,6 @@ class BaseAnalyseServiceTest(BaseCliTest):
 
         cls.cli_runner.mix_stderr = False
 
-    @staticmethod
-    def patch_check_agent_package_published(**kwargs: Any) -> mock._patch:
-        """Patch `ServiceAnalyser.check_agent_package_published` method"""
-        return mock.patch.object(
-            ServiceAnalyser, "check_agent_package_published", **kwargs
-        )
-
     @staticmethod
     def patch_check_agent_dependencies_published(**kwargs: Any) -> mock._patch:
         """Patch `ServiceAnalyser.check_agent_dependencies_published` method"""
@@ -206,37 +269,74 @@ class BaseAnalyseServiceTest(BaseCliTest):
         return mock.patch.object(IPFSTool, "all_pins", return_value=pins)
 
     @staticmethod
-    def patch_service_loader(data: List[Dict[str, Any]]) -> mock._patch:
-        """Patch service loader method"""
+    def patch_check_on_chain_state(**kwargs: Any) -> mock._patch:
+        """Patch `ServiceAnalyser.check_on_chain_state` method"""
+        return mock.patch.object(ServiceAnalyser, "check_on_chain_state", **kwargs)
 
-        config, *overrides = data
-        service = Service.from_json(config)
-        service.overrides = overrides
-
-        return mock.patch(
-            "autonomy.analyse.service.load_service_config",
-            return_value=service,
+    @staticmethod
+    def patch_ipfs_daemon_is_started(**kwargs: Any) -> mock._patch:
+        """Patch IPFSDaemon.is_started method"""
+        return mock.patch.object(
+            IPFSDaemon,
+            "is_started",
+            **kwargs,
         )
 
     @staticmethod
-    def patch_agent_loader(data: List[Dict[str, Any]]) -> mock._patch:
-        """Patch agent loader method"""
-        config, *_overrides = data
-        agent_config = AgentConfig.from_json(config)
-        if len(_overrides) > 0:
-            overrides = {}
-            for o in _overrides:
-                overrides[
-                    ComponentId(
-                        component_type=ComponentType(o.pop("type")),
-                        public_id=PublicId.from_str(o.pop("public_id")),
-                    )
-                ] = o
-            agent_config.component_configurations = overrides
+    def patch_loader(
+        service_data: List[Dict[str, Any]],
+        agent_data: List[Dict[str, Any]],
+        skill_data: Dict[str, Any],
+        is_remote: bool = False,
+    ) -> mock._patch:
+        """Patch service loader method"""
+
+        def _loader_patch(package_id: PackageId, **kargs: Any) -> Any:
+            if package_id.package_type == PackageType.SERVICE:
+                config, *overrides = service_data
+                service = Service.from_json(config)
+                service.overrides = overrides
+                return service
+
+            if package_id.package_type == PackageType.AGENT:
+                config, *_overrides = agent_data
+                agent_config = AgentConfig.from_json(config)
+                if len(_overrides) > 0:
+                    processed_overrides = {}
+                    for o in _overrides:
+                        processed_overrides[
+                            ComponentId(
+                                component_type=ComponentType(o.pop("type")),
+                                public_id=PublicId.from_str(o.pop("public_id")),
+                            )
+                        ] = o
+                    agent_config.component_configurations = processed_overrides
+                return agent_config
+
+            if package_id.package_type == PackageType.SKILL:
+                return SkillConfig.from_json(skill_data)
+
+        if is_remote:
+            return mock.patch(
+                "autonomy.cli.helpers.analyse._load_from_ipfs",
+                new=_loader_patch,
+            )
 
         return mock.patch(
-            "autonomy.cli.helpers.analyse._load_agent_from_ipfs",
-            return_value=agent_config,
+            "autonomy.cli.helpers.analyse._load_from_local",
+            new=_loader_patch,
+        )
+
+    @staticmethod
+    def patch_get_on_chain_service_id() -> mock._patch:
+        """Patch _get_on_chain_service_id"""
+
+        return mock.patch(
+            "autonomy.cli.helpers.analyse._get_on_chain_service_id",
+            return_value=PackageId(
+                package_type=PackageType.SERVICE,
+                public_id=PublicId.from_str(f"valory/service:{DUMMY_SERVICE_HASH}"),
+            ),
         )
 
 
@@ -249,37 +349,39 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
         skill_config = get_dummy_overrides_skill()
         del skill_config["models"]["params"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), skill_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[get_dummy_service_config(), skill_config],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
             "ABCI skill validation failed; 'params' is a required property"
             in result.stderr
-        )
+        ), result.stdout
 
-    def test_abci_skill_required_arg_not_defined(self) -> None:
+    def test_abci_skill_required_arg_not_defined(self, caplog: Any) -> None:
         """Test successful run."""
 
         skill_config = get_dummy_overrides_skill()
         del skill_config["models"]["params"]["args"]["tendermint_url"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), skill_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[get_dummy_service_config(), skill_config],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]), caplog.at_level(logging.WARNING):
+            result = self.run_cli(commands=self.public_id_option)
 
-        assert result.exit_code == 1, result.stdout
+        assert result.exit_code == 0, result.stdout
         assert (
-            "Error: ABCI skill validation failed; 'tendermint_url' is a required property"
-            in result.stderr
+            "ServiceAnalyser:service.py:284 (agent, valory/dummy_agent:0.1.0) contains configuration which is missing from (service, valory/dummy_service:0.1.0)"
+            in caplog.text
         )
+        assert "Path: models.params.args" in caplog.text
+        assert "Missing parameters: {'tendermint_url'}" in caplog.text
 
     def test_abci_skill_setup_param_not_defined(self) -> None:
         """Test successful run."""
@@ -288,12 +390,12 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
 
         del skill_config["models"]["params"]["args"]["setup"]["all_participants"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), skill_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[get_dummy_service_config(), skill_config],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
@@ -307,12 +409,16 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
         connection_config = get_dummy_overrides_ledger_connection()
         del connection_config["config"]["ledger_apis"]["ethereum"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), connection_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[
+                get_dummy_service_config(),
+                get_dummy_overrides_skill(),
+                connection_config,
+            ],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
@@ -328,14 +434,16 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
             "config"
         ]["ledger_apis"]["ethereum"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), connection_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ), caplog.at_level(
-            logging.WARN
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[
+                get_dummy_service_config(),
+                get_dummy_overrides_skill(),
+                connection_config,
+            ],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]), caplog.at_level(logging.WARNING):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert "Unknown ledger configuration found with name `solana`" in caplog.text
@@ -346,12 +454,16 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
         connection_config = get_dummy_overrides_ledger_connection()
         del connection_config["config"]["ledger_apis"]["ethereum"]["address"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), connection_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[
+                get_dummy_service_config(),
+                get_dummy_overrides_skill(),
+                connection_config,
+            ],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
@@ -365,12 +477,16 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
         connection_config = get_dummy_overrides_abci_connection()
         del connection_config["config"]["host"]
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), connection_config]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ):
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[
+                get_dummy_service_config(),
+                get_dummy_overrides_skill(),
+                connection_config,
+            ],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]):
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
@@ -379,24 +495,30 @@ class TestCheckRequiredOverrides(BaseAnalyseServiceTest):
         )
 
 
-class TestCheckAgentPackagePublished(BaseAnalyseServiceTest):
+class TestCheckAgentDependenciesPublished(BaseAnalyseServiceTest):
     """Test `check_agent_package_published` method."""
 
-    def test_agent_not_found(self) -> None:
+    def test_dependency_not_found(self) -> None:
         """Test failure."""
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), get_dummy_overrides_skill()]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ), self.patch_validate_service_overrides():
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[get_dummy_service_config(), get_dummy_overrides_skill()],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+            is_remote=True,
+        ), self.patch_ipfs_tool(
+            []
+        ), self.patch_validate_service_overrides(), self.patch_ipfs_daemon_is_started(
+            return_value=True,
+        ), self.patch_get_on_chain_service_id(), self.patch_check_on_chain_state():
+            result = self.run_cli(commands=self.token_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
-            "Agent package for service valory/dummy_service:0.1.0 not published on the IPFS registry"
+            "Error: Package required for service valory/dummy_service:0.1.0 is not published on the IPFS registry"
             in result.stderr
         )
+        assert "agent: valory/dummy_agent:0.1.0" in result.stderr
 
 
 class TestVerifyOverrides(BaseAnalyseServiceTest):
@@ -405,37 +527,21 @@ class TestVerifyOverrides(BaseAnalyseServiceTest):
     def test_missing_override(self) -> None:
         """Test missing override section from agent config."""
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), get_dummy_overrides_skill()]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ), self.patch_validate_service_overrides(), self.patch_check_agent_package_published():
-            result = self.run_cli(commands=(str(self.t),))
+        with self.patch_loader(
+            service_data=[
+                get_dummy_service_config(),
+                get_dummy_overrides_skill(),
+                get_dummy_overrides_ledger_connection(),
+            ],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+        ), self.patch_ipfs_tool([]), self.patch_validate_service_overrides():
+            result = self.run_cli(commands=self.public_id_option)
 
         assert result.exit_code == 1, result.stdout
         assert (
-            "Service config has an overrides which are not defined in the agent config; "
-            "packages with missing overrides={PackageId(skill, valory/abci_skill:0.1.0)}"
-            in result.stderr
-        )
-
-
-class TestCheckAgentDependenciesPublished(BaseAnalyseServiceTest):
-    """Test `check_agent_dependencies_published` method."""
-
-    def test_dependency_missing_from_ipfs(self) -> None:
-        """Test missing dependency"""
-
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), get_dummy_overrides_skill()]
-        ), self.patch_ipfs_tool([]), self.patch_agent_loader(
-            data=[get_dummy_agent_config()]
-        ), self.patch_validate_service_overrides(), self.patch_check_agent_package_published(), self.patch_verify_overrides():
-            result = self.run_cli(commands=(str(self.t),))
-
-        assert result.exit_code == 1, result.stdout
-        assert (
-            "Package required for service valory/dummy_service:0.1.0 is not published on the IPFS registry"
+            "Error: Service config has an overrides which are not defined in the agent config;"
+            " packages with missing overrides={PackageId(connection, valory/ledger:0.1.0)}"
             in result.stderr
         )
 
@@ -443,18 +549,30 @@ class TestCheckAgentDependenciesPublished(BaseAnalyseServiceTest):
 class TestCheckOnChainState(BaseAnalyseServiceTest):
     """Test `check_on_chain_state` method."""
 
-    def test_on_chain_status_check(self) -> None:
+    def test_on_chain_status_check(self, caplog: Any) -> None:
         """Test `check_on_chain_state` failure"""
 
-        with self.patch_service_loader(
-            data=[get_dummy_service_config(), get_dummy_overrides_skill()]
+        with self.patch_loader(
+            service_data=[get_dummy_service_config(), get_dummy_overrides_skill()],
+            agent_data=[get_dummy_agent_config(), get_dummy_overrides_skill()],
+            skill_data=get_dummy_skill_config(),
+            is_remote=True,
         ), mock.patch(
             "autonomy.analyse.service.get_service_info", return_value=[None, 0, None]
+        ), self.patch_ipfs_tool(
+            []
+        ), self.patch_ipfs_daemon_is_started(
+            return_value=True,
+        ), self.patch_get_on_chain_service_id(), caplog.at_level(
+            logging.WARNING
         ):
-            result = self.run_cli(commands=(str(self.t), "--token-id", "1"))
+            result = self.run_cli(commands=self.token_id_option)
 
         assert result.exit_code == 1, result.stdout
-        assert "Service needs to be in deployed state on-chain" in result.stderr
+        assert (
+            "Service needs to be in deployed state on-chain; Current state=ServiceState.NON_EXISTENT"
+            in caplog.text
+        )
 
 
 class TestCheckSuccessful(BaseAnalyseServiceTest):
@@ -468,13 +586,21 @@ class TestCheckSuccessful(BaseAnalyseServiceTest):
         for i in range(4):
             skill_config[i] = {"models": deepcopy(models)}
 
-        with self.patch_service_loader(
-            data=[
+        with self.patch_loader(
+            service_data=[
                 get_dummy_service_config(),
                 skill_config,
                 get_dummy_overrides_abci_connection(),
                 get_dummy_overrides_ledger_connection(),
-            ]
+            ],
+            agent_data=[
+                get_dummy_agent_config(),
+                get_dummy_overrides_skill(),
+                get_dummy_overrides_abci_connection(),
+                get_dummy_overrides_ledger_connection(),
+            ],
+            skill_data=get_dummy_skill_config(),
+            is_remote=True,
         ), self.patch_ipfs_tool(
             pins=list(
                 map(
@@ -487,15 +613,13 @@ class TestCheckSuccessful(BaseAnalyseServiceTest):
                     ],
                 )
             )
-        ), self.patch_agent_loader(
-            data=[
-                get_dummy_agent_config(),
-                get_dummy_overrides_skill(),
-                get_dummy_overrides_abci_connection(),
-                get_dummy_overrides_ledger_connection(),
-            ]
+        ), self.patch_ipfs_daemon_is_started(
+            return_value=True,
+        ), self.patch_get_on_chain_service_id(), mock.patch(
+            "autonomy.analyse.service.get_service_info",
+            return_value=(None, 4, None),
         ):
-            result = self.run_cli(commands=(str(self.t),))
+            result = self.run_cli(commands=self.token_id_option)
 
         assert result.exit_code == 0, result.stderr
         assert "Service is ready to be deployed" in result.output
