@@ -43,6 +43,7 @@ from autonomy.deploy.constants import (
 from autonomy.deploy.generators.docker_compose.base import DockerComposeGenerator
 
 from tests.conftest import ROOT_DIR, skip_docker_tests
+from tests.test_autonomy.base import get_dummy_service_config
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
@@ -71,9 +72,23 @@ class BaseDeployBuildTest(BaseCliTest):
         )
         os.chdir(self.t / "hello_world")
 
+    @staticmethod
+    def load_kubernetes_config(
+        path: Path,
+    ) -> List[Dict]:
+        """Load kubernetes config."""
 
-class TestDockerComposeBuilds(BaseDeployBuildTest):
-    """Test docker-compose build."""
+        with open(path / "build.yaml", "r") as fp:
+            return list(yaml.safe_load_all(fp))
+
+    @classmethod
+    def check_kubernetes_build(cls, build_dir: Path) -> None:
+        """Check kubernetes build dir."""
+
+        build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
+        assert any(
+            child in build_tree for child in ["persistent_storage", "build.yaml"]
+        )
 
     @staticmethod
     def load_and_check_docker_compose_file(
@@ -116,6 +131,10 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
             ]
         )
 
+
+class TestDockerComposeBuilds(BaseDeployBuildTest):
+    """Test docker-compose build."""
+
     def test_docker_compose_build(
         self,
     ) -> None:
@@ -128,7 +147,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                 )
             )
@@ -157,7 +175,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                     "--local-tm-setup",
                 )
@@ -178,7 +195,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -215,7 +231,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--dev",
                     "--local",
                     "--packages-dir",
@@ -260,7 +275,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--password",
                     ETHEREUM_ENCRYPTION_PASSWORD,
                     "--local",
@@ -312,7 +326,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--dev",
                     "--local",
                     "--packages-dir",
@@ -348,7 +361,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--dev",
                     "--local",
                 )
@@ -390,7 +402,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -427,7 +438,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -455,32 +465,6 @@ class TestDockerComposeBuilds(BaseDeployBuildTest):
 class TestKubernetesBuild(BaseDeployBuildTest):
     """Test kubernetes builds."""
 
-    @staticmethod
-    def load_kubernetes_config(
-        path: Path,
-    ) -> List[Dict]:
-        """Load kubernetes config."""
-
-        with open(path / "build.yaml", "r") as fp:
-            return list(yaml.safe_load_all(fp))
-
-    @classmethod
-    def check_kubernetes_build(cls, build_dir: Path) -> None:
-        """Check kubernetes build dir."""
-
-        build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
-        assert any(
-            child in build_tree for child in ["persistent_storage", "build.yaml"]
-        )
-
-        kubernetes_config = cls.load_kubernetes_config(path=build_dir)
-        assert all(
-            [
-                resource["metadata"]["name"] != "config-nodes"
-                for resource in kubernetes_config
-            ]
-        )
-
     def test_kubernetes_build(
         self,
     ) -> None:
@@ -494,7 +478,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
-                    "--force",
                     "--local",
                 )
             )
@@ -517,7 +500,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -547,7 +529,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
-                    "--force",
                     "--dev",
                     "--local",
                     "--packages-dir",
@@ -579,7 +560,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     str(keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--kubernetes",
                     "--password",
                     ETHEREUM_ENCRYPTION_PASSWORD,
@@ -624,7 +604,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     str(self.keys_file),
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
-                    "--force",
                     "--local",
                     "--kubernetes",
                     "--local-tm-setup",
@@ -657,7 +636,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -689,7 +667,6 @@ class TestKubernetesBuild(BaseDeployBuildTest):
                     "--o",
                     str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
-                    "--force",
                     "--local",
                     "--log-level",
                     DEBUG,
@@ -706,3 +683,69 @@ class TestKubernetesBuild(BaseDeployBuildTest):
         build_config = self.load_kubernetes_config(build_dir)
         assert f"'image': '{image_author}/oar-" in str(build_config)
         assert f"'image': '{DEFAULT_DOCKER_IMAGE_AUTHOR}/oar-" not in str(build_config)
+
+
+class TestExposePorts(BaseDeployBuildTest):
+    """Test expose ports from service config."""
+
+    def setup(self) -> None:
+        """Setup test."""
+        super().setup()
+
+        service_data = get_dummy_service_config(file_number=1)
+        service_data[0]["deployment"] = {"agent": {"ports": {0: {8080: 8081}}}}
+
+        with open("./service.yaml", "w+") as fp:
+            yaml.dump_all(service_data, fp)
+
+    def test_expose_agent_ports_docker_compose(self) -> None:
+        """Test expose agent ports"""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_docker_compose_build(
+            build_dir=build_dir,
+        )
+
+        docker_compose = self.load_and_check_docker_compose_file(
+            path=build_dir / DockerComposeGenerator.output_name
+        )
+
+        assert docker_compose["services"]["abci0"]["ports"] == ["8080:8081"]
+
+    def test_expose_agent_ports_kubernetes(self) -> None:
+        """Test expose agent ports"""
+
+        build_dir = self.t / DEFAULT_BUILD_FOLDER
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--kubernetes",
+                )
+            )
+
+        assert result.exit_code == 0, result.output
+        assert build_dir.exists()
+
+        self.check_kubernetes_build(build_dir=build_dir)
+
+        build_config = self.load_kubernetes_config(build_dir)
+
+        assert "ports" in build_config[1]["spec"]["template"]["spec"]["containers"][1]
+        assert build_config[1]["spec"]["template"]["spec"]["containers"][1][
+            "ports"
+        ] == [{"containerPort": 8080}]
