@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -21,16 +21,12 @@
 import os
 import re
 from enum import Enum
-from functools import partial
 from pathlib import Path
 from typing import Callable, Dict, List, Optional
 
-import mistune  # type: ignore
-
 from tests.conftest import ROOT_DIR
 
 
-MISTUNE_BLOCK_CODE_ID = "block_code"
 IPFS_HASH_REGEX = r"bafybei[A-Za-z0-9]{52}"
 PYTHON_LINE_COMMENT_REGEX = r"^#.*\n"
 DOC_ELLIPSIS_REGEX = r"\s*#\s...\n"
@@ -50,36 +46,23 @@ class CodeType(Enum):
     NOCODE = "nocode"
 
 
-def block_code_filter(b: Dict) -> bool:
-    """Check Mistune block is a code block."""
-    return b["type"] == MISTUNE_BLOCK_CODE_ID
+def dedent_code(code: str, n_spaces: int) -> str:
+    """Removes n characters at the begining of each line"""
+    lines = [line[n_spaces:] for line in code.split("\n")]
+    return "\n".join(lines)
 
 
-def type_filter(type_: Optional[str], b: Dict) -> bool:
-    """
-    Check Mistune code block is of a certain type.
-
-    If the field "info" is None, return False.
-    If type_ is None, this function always return true.
-
-    :param type_: the expected type of block (optional)
-    :param b: the block dicionary.
-    :return: True if the block should be accepted, false otherwise.
-    """
-    if type_ is None:
-        return True
-    return b["info"].strip() == type_ if b["info"] is not None else False
-
-
-def extract_code_blocks(filepath: str, filter_: Optional[str] = None) -> list:
+def extract_code_blocks(filepath: str, filter_: Optional[str] = None) -> List[str]:
     """Extract code blocks from .md files."""
     content = Path(filepath).read_text(encoding="utf-8")
-    markdown_parser = mistune.create_markdown(renderer=mistune.AstRenderer())
-    blocks = markdown_parser(content)
-    actual_type_filter = partial(type_filter, filter_)
-    code_blocks = list(filter(block_code_filter, blocks))
-    bash_code_blocks = filter(actual_type_filter, code_blocks)
-    return list(b["text"] for b in bash_code_blocks)
+    code_blocks = re.findall(
+        rf"([ \t]*)```{filter_}\n(.+?)[ \t]*```", content, flags=re.DOTALL
+    )
+
+    dedented_code_blocks = [
+        dedent_code(code, len(indent)) for indent, code in code_blocks
+    ]
+    return dedented_code_blocks
 
 
 def extract_python_code(filepath: str) -> str:
@@ -150,7 +133,7 @@ def check_code_blocks_exist(
         list(map(doc_process_fn, code_blocks)) if doc_process_fn else code_blocks
     )
 
-    # Ensure the code block mapping is correct. We ned a code file for each code block in the doc file
+    # Ensure the code block mapping is correct. We need a code file for each code block in the doc file
     assert len(code_blocks) == len(
         code_files
     ), f"Doc checker found {len(code_blocks)} non-skipped code blocks in {md_file} but only {len(code_files)} are being checked"
@@ -172,6 +155,7 @@ def check_code_blocks_exist(
                     line in code
                 ), f"This line in {md_file} doesn't exist in the code file {code_file}:\n\n'{line}'"
             continue
+
         assert (
             code_blocks[i] in code
         ), f"This code-block in {md_file} doesn't exist in the code file {code_file}:\n\n{code_blocks[i]}"
